==> quick_resto_API-1.0.13.tar.gz: quick_resto_API-1.0.13/quick_resto_API/operations_with_objects/modules/store_item_tag_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.store_item_tag import StoreItemTag

class StoreItemTagOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.storeitemtag"

    def get_list_of_store_item_tag(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(StoreItemTag(**object))

        return result

    def get_tree_of_store_item_tag(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(StoreItemTag(**object))

        return result

    def get_store_item_tag(self, objectId: int, objectRid: int = None) -> StoreItemTag:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return StoreItemTag(**json_response)

    def get_store_item_tag_with_subobjects(self, objectId: int, objectRid: int = None) -> StoreItemTag:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return StoreItemTag(**json_response)

    def create_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def update_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def remove_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def recover_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

==> quick_resto_API-1.1.2.tar.gz: quick_resto_API-1.1.2/quick_resto_API/operations_with_objects/modules/store_item_tag_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.store_item_tag import StoreItemTag

class StoreItemTagOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.storeitemtag"

    def get_list_of_store_item_tag(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[StoreItemTag]:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[StoreItemTag] = list()

        for object in json_response:
            result.append(StoreItemTag(**object))

        return result

    def get_tree_of_store_item_tag(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[StoreItemTag]:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[StoreItemTag] = list()

        for object in json_response:
            result.append(StoreItemTag(**object))

        return result

    def get_store_item_tag(self, objectId: int, objectRid: int = None) -> StoreItemTag:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return StoreItemTag(**json_response)

    def get_store_item_tag_with_subobjects(self, objectId: int, objectRid: int = None) -> StoreItemTag:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return StoreItemTag(**json_response)

    def create_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def update_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def remove_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)

    def recover_store_item_tag(self, object: StoreItemTag,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> StoreItemTag:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return StoreItemTag(**json_response)
